@@ -9,6 +9,7 @@ from kks.cmd.sync import sync
 from kks.cmd.status import status
 from kks.cmd.test import test
 from kks.cmd.top import top
+from kks.cmd.open import open
 
 
 @click.group()
@@ -25,3 +26,4 @@ cli.add_command(lint)
 cli.add_command(sync)
 cli.add_command(status)
 cli.add_command(top)
+cli.add_command(open)
