@@ -4,16 +4,15 @@ from pathlib import Path
 import click
 from tqdm import tqdm
 
-from kks.util import get_solution_directory, find_test_output, format_file, test_number_to_name, find_test_pairs, \
-    get_matching_suffix
+from kks.util import get_solution_directory, format_file, test_number_to_name, find_test_pairs, get_matching_suffix
 
 
-@click.command(short_help='Run solution')
+@click.command(short_help='Generate tests')
 @click.option('-o', '--output-only', is_flag=True,
               help='If specified, only solution will be run. Useful to generate output for manually created tests')
-@click.option('-g', '--generator', type=click.Path(exists=True), multiple=True,
+@click.option('-g', '--generator', type=click.Path(exists=True),
               help='Script, used to generate .in files')
-@click.option('-s', '--solution', type=click.Path(exists=True), multiple=True,
+@click.option('-s', '--solution', type=click.Path(exists=True),
               help='Script, used to generate .out files')
 @click.option('-t', '--test', 'tests', type=int, multiple=True,
               help='Test number to generate')
@@ -50,16 +49,20 @@ def gen(output_only, generator, solution, tests, test_range, force, gen_args):
     test_pairs = find_tests_to_gen(directory, tests, test_range, output_only)
     test_pairs = sorted(test_pairs)
 
+    generated_tests = 0
+
     t = tqdm(test_pairs, leave=False)
     for input_file, output_file in t:
         if not output_only and input_file.exists() and not force:
-            click.secho(f'Input file {format_file(input_file)} '
-                        f'already exists, skipping. Specify -f to overwrite', fg='yellow', err=True)
+            t.clear()
+            click.secho(f'Input file ' + format_file(input_file), fg='yellow', err=True, nl=False)
+            click.secho(f' already exists, skipping. Specify -f to overwrite', fg='yellow', err=True)
             continue
 
-        if output_file.exists() and not force:
-            click.secho(f'Output file {format_file(output_file)} '
-                        f'already exists, skipping. Specify -f to overwrite', fg='yellow', err=True)
+        if output_file and output_file.exists() and not force:
+            t.clear()
+            click.secho(f'Output file ' + format_file(output_file), fg='yellow', err=True, nl=False)
+            click.secho(f' already exists, skipping. Specify -f to overwrite', fg='yellow', err=True)
             continue
 
         t.set_description(f'Generating test {format_file(input_file)}')
@@ -75,39 +78,41 @@ def gen(output_only, generator, solution, tests, test_range, force, gen_args):
             if run_binary(solution, args, stdin=f_in, stdout=f_out) is None:
                 return
 
-    click.secho('Generated tests!', fg='green', err=True)
+        generated_tests += 1
+
+    click.secho(f'Generated {generated_tests} tests!', fg='green', err=True)
 
 
 def find_tests_to_gen(directory, tests, test_range, output_only):
     """Находит существующие тесты"""
     tests_dir = directory / 'tests'
-    tests_dir.mkdir(exists_ok=True)
+    tests_dir.mkdir(exist_ok=True)
 
-    test_numbers = tests
+    if not tests and not test_range:
+        test_range = (1, 100)
+
+    test_numbers = list(tests)
     if test_range:
         l, r = sorted(test_range)
         test_numbers += list(range(l, r + 1))
 
     test_names = [test_number_to_name(number) for number in test_numbers]
 
-    pairs = find_test_pairs(tests_dir, test_names)
+    pairs = list(find_test_pairs(tests_dir, test_names))
 
     used_names = [input_file.stem for input_file, _ in pairs]
     not_used_names = set(test_names) - set(used_names)
 
     def output_file_for_input_file(input_file):
-        return input_file.with_suffix(get_matching_suffix(input_file))
+        return input_file.with_suffix(get_matching_suffix(input_file.suffix))
 
     result = []
 
-    # Добавляем выходной файл, если генерируем только out
-    if not output_only:
-        result += pairs
-    else:
-        result += [
-            (input_file, output_file or output_file_for_input_file(input_file))
-            for input_file, output_file in pairs
-        ]
+    # Добавляем выходной файл, если его не существует
+    result += [
+        (input_file, output_file or output_file_for_input_file(input_file))
+        for input_file, output_file in pairs
+    ]
 
     # Если пары совсем не существует, добавляем
     result += [
@@ -120,17 +125,17 @@ def find_tests_to_gen(directory, tests, test_range, output_only):
 
 
 def run_binary(binary, args, stdin=None, stdout=None):
-    ext = binary.stem
+    ext = binary.suffix
 
     interpreter = 'python3' if ext in ['.py', '.py3'] \
         else 'bash' if ext in ['.sh'] \
         else None
 
-    if interpreter:
-        click.secho(f'Cant run Unrecognized file {format_file(binary)}', fg='red', err=True)
+    if interpreter is None:
+        click.secho(f'Cant run unrecognized script {format_file(binary)}', fg='red', err=True)
         return None
 
-    process = subprocess.run(['python3', binary] + args, stdin=stdin, stdout=stdout)
+    process = subprocess.run([interpreter, binary] + args, stdin=stdin, stdout=stdout)
 
     if process.returncode != 0:
         click.secho('Script exited with code ' +
