@@ -83,13 +83,17 @@ def get_contest_id(group_id):
     return CONTEST_ID_BY_GROUP.get(group_id, None)
 
 
-def ejudge_auth(auth_data, session):
+def get_contest_url(auth_data):
     url = f'https://caos.ejudge.ru/ej/client?contest_id={auth_data.contest_id}'
+    if auth_data.login is not None and auth_data.password is not None:
+        url += f'&login={auth_data.login}&password={auth_data.password}'
+    return url
 
-    page = session.post(url, data={
-        'login': auth_data.login,
-        'password': auth_data.password
-    })
+
+def ejudge_auth(auth_data, session):
+    url = get_contest_url(auth_data)
+
+    page = session.get(url)
 
     if page.status_code != requests.codes.ok:
         click.secho(f'Failed to authenticate (status code {page.status_code})', err=True, fg='red')
